﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

using Foundation;
using UIKit;

namespace Todo_Liste
{
    class TodoDataSource : UITableViewSource
    {
        public List<Task> taskList;
        string cellIdentifier = "TableCell";
        ViewController controller;
        bool hasViewedAlert = false;
        public TodoDataSource(ViewController controller, List<Task> todoList)
        {
            this.taskList = todoList;
            this.controller = controller;
        }
        public override UITableViewCell GetCell(UITableView tableView, NSIndexPath indexPath)
        {
            UITableViewCell cell = tableView.DequeueReusableCell(cellIdentifier);

            if (cell == null) cell = new UITableViewCell(UITableViewCellStyle.Subtitle, cellIdentifier);

            int row = indexPath.Row;
            cell.TextLabel.Text = taskList[row].name;
            if(!string.IsNullOrWhiteSpace(cell.TextLabel.Text)) cell.DetailTextLabel.Text = taskList[row].createDate.Date.ToString();
            cell.BackgroundColor = UIColor.FromRGB(247, 235, 130);

            if(taskList[row].isDone)
            {
                cell.Accessory = UITableViewCellAccessory.Checkmark;
                cell.TextLabel.TextColor = UIColor.FromRGB(123, 123, 123);
            }
            else
            {
                cell.Accessory = UITableViewCellAccessory.None; 
                cell.TextLabel.TextColor = UIColor.FromRGB(128, 0, 128);
                cell.TextLabel.Font = UIFont.FromName("Chalkduster", 20);
            }

            return cell;
        }
        public override nint RowsInSection(UITableView tableview, nint section)
        {
            return taskList.Count();
        }
        public override bool CanEditRow(UITableView tableView, NSIndexPath indexPath)
        {
            return true;
        }
        public override void CommitEditingStyle(UITableView tableView, UITableViewCellEditingStyle editingStyle, NSIndexPath indexPath)
        {
            switch(editingStyle)
            {
                case UITableViewCellEditingStyle.Delete:
                    taskList.RemoveAt(indexPath.Row);
                    tableView.DeleteRows(new NSIndexPath[] { indexPath }, UITableViewRowAnimation.Fade);
                    break;
                case UITableViewCellEditingStyle.Insert:
                    controller.alertDialog();
                    break;
            }
        }
        public override void RowSelected(UITableView tableView, NSIndexPath indexPath)
        {
            Task currentTask = taskList[indexPath.Row];
            currentTask.isDone = !currentTask.isDone;
            tableView.ReloadData();
        }
        public override UITableViewCellEditingStyle EditingStyleForRow(UITableView tableView, NSIndexPath indexPath)
        {
            if (tableView.Editing)
            {
                if (indexPath.Row == tableView.NumberOfRowsInSection(0) - 1) return UITableViewCellEditingStyle.Insert;
                else return UITableViewCellEditingStyle.Delete;
            }
            else return UITableViewCellEditingStyle.None;
        }
        public void WillBeginTableEditing(UITableView tableView)
        {
            tableView.BeginUpdates();
            tableView.InsertRows(new NSIndexPath[] { NSIndexPath.FromRowSection(tableView.NumberOfRowsInSection(0), 0 ) }, UITableViewRowAnimation.Fade);
            taskList.Add(new Task());
            tableView.EndUpdates();
        }
        public void DidFinishTableEditing(UITableView tableView)
        {
            tableView.BeginUpdates();
            taskList.RemoveAt((int)tableView.NumberOfRowsInSection(0) - 1);
            tableView.DeleteRows(new NSIndexPath[] { NSIndexPath.FromRowSection(tableView.NumberOfRowsInSection(0) - 1, 0) }, UITableViewRowAnimation.Fade);
            tableView.EndUpdates();
        }
        public override UISwipeActionsConfiguration GetLeadingSwipeActionsConfiguration(UITableView tableView, NSIndexPath indexPath)
        {
            var flagAction = ContextualFlagAction(indexPath.Row);
            var deleteAction = ContextualDeleteAction(tableView, indexPath.Row);

            var leadingSwipe = UISwipeActionsConfiguration.FromActions(new UIContextualAction[] { flagAction, deleteAction });

            leadingSwipe.PerformsFirstActionWithFullSwipe = false;

            return leadingSwipe;
        }
        public UIContextualAction ContextualDeleteAction(UITableView tableView, int row)
        {
            var action = UIContextualAction.FromContextualActionStyle(UIContextualActionStyle.Normal,
                "Delete",
                (ReadLaterAction, view, success) => {
                    tableView.BeginUpdates();
                    taskList.RemoveAt(row);
                    tableView.DeleteRows(new NSIndexPath[] { NSIndexPath.FromRowSection(tableView.NumberOfRowsInSection(0) - 1, 0) }, UITableViewRowAnimation.Fade);
                    tableView.EndUpdates();
                });
            action.BackgroundColor = UIColor.Red;
            return action;
        }
        public UIContextualAction ContextualFlagAction(int row)
        {
            var action = UIContextualAction.FromContextualActionStyle(UIContextualActionStyle.Normal,
                "Edit",
                (FlagAction, view, success) => {
                    var alertController = UIAlertController.Create($"Report {taskList[row].name}?", "", UIAlertControllerStyle.Alert);
                    alertController.AddAction(UIAlertAction.Create("Cancel", UIAlertActionStyle.Cancel, null));
                    alertController.AddAction(UIAlertAction.Create("Yes", UIAlertActionStyle.Destructive, null));
                    controller.PresentViewController(alertController, true, null);

                    success(true);
                });

            //action.Image = UIImage.FromFile("Editing-Edit-icon.png");
            action.BackgroundColor = UIColor.Blue;

            return action;
        }
    }
}