﻿using Foundation;
using System;
using System.Collections.Generic;
using UIKit;

namespace Todo_Liste
{
    public partial class ViewController : UIViewController
    {
        public List<Task> taskList { get; set; }
        TodoDataSource tableSource;
        public ViewController (IntPtr handle) : base (handle)
        {
            taskList = new List<Task>();
        }
        public override void ViewDidLoad ()
        {
            base.ViewDidLoad ();
            btnAddTask.TouchUpInside += BtnAddTask_TouchUpInside;
            btnEditTask.TouchUpInside += BtnEditTask_TouchUpInside;
            btnDeleteTask.TouchUpInside += BtnDeleteTask_TouchUpInside;

            tableSource = new TodoDataSource(this, taskList);
            tvTodos.Source = tableSource;
            tvTodos.BackgroundColor = UIColor.FromRGB(247, 235, 130);
            tvTodos.AddGestureRecognizer(new UILongPressGestureRecognizer(LongPress));
            tvTodos.AddGestureRecognizer(new UISwipeGestureRecognizer(SwipeLeftToRight)
            {
                Direction = UISwipeGestureRecognizerDirection.Right
            });
        }
        private void BtnDeleteTask_TouchUpInside(object sender, EventArgs e)
        {
            this.taskList.Clear();
            tvTodos.ReloadData();
        }
        private void BtnEditTask_TouchUpInside(object sender, EventArgs e)
        {
            if (tvTodos.Editing)
            {
                tvTodos.SetEditing(!tvTodos.Editing, !tvTodos.Editing);
                tableSource.DidFinishTableEditing(tvTodos);
                btnAddTask.Enabled = true;
            }
            else
            {
                tableSource.WillBeginTableEditing(tvTodos);
                tvTodos.SetEditing(!tvTodos.Editing, !tvTodos.Editing);
                btnAddTask.Enabled = false;
            }
        }
        private void BtnAddTask_TouchUpInside(object sender, EventArgs e)
        {
            if(txtTodo.Text.Length > 0) taskList.Add(new Task(txtTodo.Text));
            txtTodo.Text = "";
            tvTodos.ReloadData();
        }
        public override void DidReceiveMemoryWarning ()
        {
            base.DidReceiveMemoryWarning ();
            // Release any cached data, images, etc that aren't in use.
        }
        public void alertDialog()
        {
            UIAlertController alertController = UIAlertController.Create(
                "Task hinzufügen",
                "Bitte Taskbeschreibung angeben",
                UIAlertControllerStyle.Alert);
            UITextField txtAddTask = null;
            alertController.AddTextField(AddTaskTxt =>
            {
                txtAddTask = AddTaskTxt;
                txtAddTask.Placeholder = "Hier Taskbeschreibung einfügen";
            });
            alertController.AddAction(UIAlertAction.Create(
                "Ok",
                UIAlertActionStyle.Default,
                onClick =>
                {
                    if(txtAddTask.Text.Length > 0)
                    {
                        taskList.RemoveAt(taskList.Count - 1);
                        taskList.Add(new Task(txtAddTask.Text));
                        taskList.Add(new Task());
                        tvTodos.ReloadData();
                    }
                }));
            alertController.AddAction(UIAlertAction.Create("Abbrechen", UIAlertActionStyle.Cancel, null));
            PresentViewController(alertController, true, null);
        }
        private void LongPress(UILongPressGestureRecognizer longPressGestureRecognizer)
        {
            if(longPressGestureRecognizer.State == UIGestureRecognizerState.Began) EditAlertDialog(tvTodos.IndexPathForRowAtPoint(longPressGestureRecognizer.LocationInView(tvTodos)));
        }
        private void EditAlertDialog(NSIndexPath indexPath)
        {
            Task currentTask = taskList[indexPath.Row];
            UIAlertController alertController = UIAlertController.Create(
                "Task bearbeiten",
                "Bitte Taskbeschreibung ändern",
                UIAlertControllerStyle.Alert);
            UITextField txtEditTask = null;
            alertController.AddTextField(EditTaskTxt =>
            {
                txtEditTask = EditTaskTxt;
                txtEditTask.Text = currentTask.name;
            });
            alertController.AddAction(UIAlertAction.Create(
                "Ok",
                UIAlertActionStyle.Default,
                onClick =>
                {
                    if (txtEditTask.Text.Length > 0)
                    {
                        currentTask.name = txtEditTask.Text;
                        taskList[indexPath.Row].name = currentTask.name;
                        tvTodos.BeginUpdates();
                        tvTodos.ReloadRows(tvTodos.IndexPathsForVisibleRows, UITableViewRowAnimation.Automatic);
                        tvTodos.EndUpdates();
                    }
                }));
            alertController.AddAction(UIAlertAction.Create("Abbrechen", UIAlertActionStyle.Cancel, null));
            PresentViewController(alertController, true, null);

        }
        private void SwipeLeftToRight(UISwipeGestureRecognizer swipeGestureRecognizer)
        {
            var indexPath = tvTodos.IndexPathForRowAtPoint(swipeGestureRecognizer.LocationInView(tvTodos));
            taskList.RemoveAt(indexPath.Row);
            tvTodos.DeleteRows(new NSIndexPath[] { indexPath }, UITableViewRowAnimation.Fade);

        }
    }
}